Index: trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenu.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenu.asm	(revision 88)
+++ trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenu.asm	(revision 92)
@@ -27,5 +27,5 @@
 	cmp		cx, BYTE NO_ITEM_SELECTED
 	je		SHORT BootMenu_DisplayAndReturnSelection
-	jmp		BootMenu_ConvertMenuitemToDriveOrFunction
+	jmp		SHORT BootMenu_ConvertMenuitemFromCXtoDriveInDX
 
 
@@ -66,27 +66,4 @@
 	call	FloppyDrive_GetCount
 	add		ax, cx
-	call	BootMenu_GetMenuFunctionCount
-	add		cx, ax
-	ret
-
-;--------------------------------------------------------------------
-; Returns number of functions displayed in Boot Menu.
-;
-; BootMenu_GetMenuFunctionCount
-;	Parameters:
-;		Nothing
-;	Returns:
-;		CX:		Number of boot menu functions
-;	Corrupts registers:
-;		Nothing
-;--------------------------------------------------------------------
-ALIGN JUMP_ALIGN
-BootMenu_GetMenuFunctionCount:
-	xor		cx, cx
-	test	BYTE [cs:ROMVARS.wFlags], FLG_ROMVARS_ROMBOOT
-	jz		SHORT .DontIncludeRomBoot
-	inc		cx
-ALIGN JUMP_ALIGN
-.DontIncludeRomBoot:
 	ret
 
@@ -110,9 +87,7 @@
 
 ;--------------------------------------------------------------------
 ; Converts any hotkey to Boot Menu menuitem index.
 ;
 ; BootMenu_ConvertHotkeyToMenuitem
 ;	Parameters:
 ;		AX:		ASCII hotkey starting from upper case 'A'
 ;	Returns:
 ;		CX:		Menuitem index
@@ -121,6 +96,6 @@
 ;--------------------------------------------------------------------
 ALIGN JUMP_ALIGN
-BootMenu_ConvertHotkeyToMenuitem:
-	call	BootMenu_GetLetterForFirstHardDisk
+BootMenu_ConvertAsciiHotkeyFromALtoMenuitemInCX:
+	call	BootMenu_GetLetterForFirstHardDiskToCL
 	cmp		al, cl						; Letter is for Hard Disk?
 	jae		SHORT .StartFromHardDiskLetter
@@ -139,5 +114,5 @@
 ; can be higher if more than two floppy drives are found.
 ;
-; BootMenu_GetLetterForFirstHardDisk
+; BootMenu_GetLetterForFirstHardDiskToCL
 ;	Parameters:
 ;		Nothing
@@ -148,5 +123,5 @@
 ;--------------------------------------------------------------------
 ALIGN JUMP_ALIGN
-BootMenu_GetLetterForFirstHardDisk:
+BootMenu_GetLetterForFirstHardDiskToCL:
 	call	FloppyDrive_GetCount
 	add		cl, 'A'
@@ -156,20 +131,15 @@
 
 ;--------------------------------------------------------------------
-; Converts selected menuitem index to drive number or function ID.
-;
-; BootMenu_ConvertMenuitemToDriveOrFunction
+; BootMenu_ConvertMenuitemFromCXtoDriveInDX
 ;	Parameters:
 ;		CX:		Index of menuitem selected from Boot Menu
 ;		DS:		RAMVARS segment
 ;	Returns:
-;		DX:		Drive number to be used for booting (if CF cleared)
-;				Function ID (if CF set)
-;		CF:		Cleared if drive selected
-;				Set if function selected
-;	Corrupts registers:
-;		AX, CX
-;--------------------------------------------------------------------
-ALIGN JUMP_ALIGN
-BootMenu_ConvertMenuitemToDriveOrFunction:
+;		DX:		Drive number to be used for booting
+;	Corrupts registers:
+;		CX
+;--------------------------------------------------------------------
+ALIGN JUMP_ALIGN
+BootMenu_ConvertMenuitemFromCXtoDriveInDX:
 	mov		dx, cx					; Copy menuitem index to DX
 	call	FloppyDrive_GetCount
@@ -177,35 +147,6 @@
 	jb		SHORT .ReturnFloppyDriveInDX
 	sub		dx, cx					; Remove floppy drives from index
-	call	RamVars_GetHardDiskCountFromBDAtoCX
-	cmp		dx, cx					; Hard disk?
-	jb		SHORT .ReturnHardDiskInDX
-	sub		dx, cx					; Remove hard disks from index
-	jmp		SHORT BootMenu_ConvertFunctionIndexToID
-ALIGN JUMP_ALIGN
-.ReturnHardDiskInDX:
 	or		dl, 80h
-ALIGN JUMP_ALIGN
 .ReturnFloppyDriveInDX:
-	clc
-	ret
-
-
-;--------------------------------------------------------------------
-; Converts selected menuitem index to drive number or function ID.
-;
-; BootMenu_ConvertFunctionIndexToID
-;	Parameters:
-;		CX:		Menuitem index
-;		DX:		Function index (Menuitem index - floppy count - HD count)
-;	Returns:
-;		DX:		Function ID
-;		CF:		Set to indicate function
-;	Corrupts registers:
-;		AX, CX
-;--------------------------------------------------------------------
-ALIGN JUMP_ALIGN
-BootMenu_ConvertFunctionIndexToID:
-	mov		dx, ID_BOOTFUNC_ROMBOOT
-	stc
 	ret
 
@@ -110,9 +87,7 @@
 
 ;--------------------------------------------------------------------
-; Converts any hotkey to Boot Menu menuitem index.
-;
-; BootMenu_ConvertHotkeyToMenuitem
-;	Parameters:
-;		AX:		ASCII hotkey starting from upper case 'A'
+; BootMenu_ConvertAsciiHotkeyFromALtoMenuitemInCX
+;	Parameters:
+;		AL:		ASCII hotkey starting from upper case 'A'
 ;	Returns:
 ;		CX:		Menuitem index
